/**
 * Copyright (C) 2014-2022 Henning Norén
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
 * USA.
 */

#ifndef _SHA256_H_
#define _SHA256_H_

#include <stdint.h>

void sha256(const uint8_t *msg, const unsigned int msgLen, uint8_t *hash);
void sha256f(const uint8_t *msg, const unsigned int msgLen, uint8_t *hash);

#endif /** _SHA256_H_ */
